# CHANGELOG

<!-- version list -->

## v1.1.0 (2026-01-23)

### Features

- Stabilize versioning pipeline
  ([`03b60ae`](https://github.com/luutuankiet/gsd-lite/commit/03b60aea43e157af8f14249c09d3db84eab911af))


## v1.0.0 (2026-01-23)

- Initial Release
